@@ -13,10 +13,10 @@ using namespace std;
 extern "C" {
 /*
  * birth-death MCMC for Gaussian copula Graphical models  
- * with exact value of normalizing constant for D = I_p 
+ * for D = I_p 
  * it is for Bayesian model averaging
 */
-void bdmcmcCopulap_links( int *iter, int *burnin, int G[], double Ts[], double K[], int *p, 
+void gcgm_bdmcmc_ma( int *iter, int *burnin, int G[], double Ts[], double K[], int *p, 
 			 double Z[], int R[], int *n, int *gcgm,
 			 double K_hat[], double p_links[],
 			 int *b, int *b_star, double D[], double Ds[], double *threshold )
@@ -173,10 +173,11 @@ void bdmcmcCopulap_links( int *iter, int *burnin, int G[], double Ts[], double K
 				nu_star = b1;
 				for( k = 0; k < dim; k++ )
 					nu_star += G[i * dim + k] * G[j * dim + k];
+				nu_star = 0.5 * nu_star;   
 
-				rate = ( G[ij] ) 
-					? sqrt( Dsjj / a11 ) * exp( lgamma( ( nu_star + 1 ) / 2 ) - lgamma( nu_star / 2 ) - ( Dsij * Dsij * a11 / Dsjj  + sum_diag ) / 2 )
-					: sqrt( a11 / Dsjj ) * exp( lgamma( nu_star / 2 ) - lgamma( ( nu_star + 1 ) / 2 ) + ( Dsij * Dsij * a11 / Dsjj  + sum_diag ) / 2 );
+				rate = ( G[ij] )   // "- 1e+2" is only for dealing infinite values
+					? sqrt( 2.0 * Dsjj / a11 ) * exp( lgammafn( nu_star + 0.5 ) - lgammafn( nu_star ) - 0.5 * ( Dsij * Dsij * a11 / Dsjj + sum_diag ) - 1e+2 )
+					: sqrt( 0.5 * a11 / Dsjj ) * exp( lgammafn( nu_star ) - lgammafn( nu_star + 0.5 ) + 0.5 * ( Dsij * Dsij * a11 / Dsjj + sum_diag ) - 1e+2 );
 				
 				rates[counter++] = ( R_FINITE( rate ) ) ? rate : max_numeric_limits_ld;
 			}
@@ -229,10 +230,10 @@ void bdmcmcCopulap_links( int *iter, int *burnin, int G[], double Ts[], double K
     
 /*
  * birth-death MCMC for Gaussian copula Graphical models  
- * with exact value of normalizing constant for D = I_p 
+ * for D = I_p 
  * it is for maximum a posterior probability estimation (MAP)
 */
-void bdmcmcCopula( int *iter, int *burnin, int G[], double Ts[], double K[], int *p, 
+void gcgm_bdmcmc_map( int *iter, int *burnin, int G[], double Ts[], double K[], int *p, 
 			 double Z[], int R[], int *n, int *gcgm,
 			 int all_graphs[], double all_weights[], double K_hat[], 
 			 char *sample_graphs[], double graph_weights[], int *size_sample_g,
@@ -392,10 +393,11 @@ void bdmcmcCopula( int *iter, int *burnin, int G[], double Ts[], double K[], int
 				nu_star = b1;
 				for( k = 0; k < dim; k++ )
 					nu_star += G[i * dim + k] * G[j * dim + k];
+				nu_star = 0.5 * nu_star;   
 
-				rate = ( G[ij] ) 
-					? sqrt( Dsjj / a11 ) * exp( lgamma( ( nu_star + 1 ) / 2 ) - lgamma( nu_star / 2 ) - ( Dsij * Dsij * a11 / Dsjj  + sum_diag ) / 2 )
-					: sqrt( a11 / Dsjj ) * exp( lgamma( nu_star / 2 ) - lgamma( ( nu_star + 1 ) / 2 ) + ( Dsij * Dsij * a11 / Dsjj  + sum_diag ) / 2 );
+				rate = ( G[ij] )   // "- 1e+2" is only for dealing infinite values
+					? sqrt( 2.0 * Dsjj / a11 ) * exp( lgammafn( nu_star + 0.5 ) - lgammafn( nu_star ) - 0.5 * ( Dsij * Dsij * a11 / Dsjj + sum_diag ) - 1e+2 )
+					: sqrt( 0.5 * a11 / Dsjj ) * exp( lgammafn( nu_star ) - lgammafn( nu_star + 0.5 ) + 0.5 * ( Dsij * Dsij * a11 / Dsjj + sum_diag ) - 1e+2 );
 				
 				rates[counter] = ( R_FINITE( rate ) ) ? rate : max_numeric_limits_ld;
 				
@@ -473,5 +475,3 @@ void bdmcmcCopula( int *iter, int *burnin, int G[], double Ts[], double K[], int
 }
        
 } // End of exturn "C"
-
-
